@@ -36,18 +36,22 @@
 enum { PORTRAIT, LANDSCAPE };
 enum { NO_SPEC, TILED_BG_IMG, STRECHED_BG_IMG, SOLID_BG_COL, MBDESKTOP_BG };
 
-struct {
-	GtkWidget *toplevel;            /* top-level window */
-	  GtkWidget *vbox1;             /* top-level vertical box */
-	    GtkWidget *vpan1;
+struct window_s {
+    GtkWidget *toplevel;            /* top-level window */
+      GtkWidget *vbox1;             /* top-level vertical box */
+        GtkWidget *vpan1;
 
-	gint mode;    /* either PORTRAIT or LANDSCAPE */
-} window;
+    gint mode;    /* either PORTRAIT or LANDSCAPE */
+};
 
-struct {
+extern struct window_s window;
+
+struct conf_s {
     int bg;
     XSettingsClient *xst_client;
-} conf;
+};
+
+extern struct conf_s conf;
 
 struct myscroll {
 	GtkAdjustment *adjust;
@@ -63,12 +67,6 @@ void myscroll_update_upper_adjust(struct myscroll *scroll);
 
 void markup_printf(PangoLayout *pl, const char *fmt, ...);
 
-int load_pixmap_non_critical(const char *path, GdkPixmap **pixmap,
-                             GdkBitmap **mask, int alpha);
-
-void load_pixmap(const char *path, GdkPixmap **pixmap, GdkBitmap **mask,
-                 int alpha);
-
 void set_background(const char *spec);
 
 #endif /* !HAVE_TODAY_H */
